<?xml version="1.0" encoding="utf-8"?>

<!-- Original German translation done by Frank Tegtmeyer -->

<!DOCTYPE TS>
<TS version="2.1" language="de">
<context>
    <name>DialogSettings</name>
    <message>
        <location filename="../ui/dialogsettings.ui" line="14"/>
        <source>Dialog</source>
        <translatorcomment>not sure about the use</translatorcomment>
        <translation>Einstellungen</translation>
    </message>
    <message>
        <location filename="../ui/dialogsettings.ui" line="221"/>
        <source>Internet updates</source>
        <translation>Aktualisierungen über Internet</translation>
    </message>
    <message>
        <location filename="../ui/dialogsettings.ui" line="230"/>
        <source>Update now</source>
        <translation>Jetzt aktualisieren</translation>
    </message>
    <message>
        <location filename="../ui/dialogsettings.ui" line="30"/>
        <source>Layout</source>
        <translation>Anordnung</translation>
    </message>
    <message>
        <location filename="../ui/dialogsettings.ui" line="24"/>
        <source>Interface</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/dialogsettings.ui" line="64"/>
        <source>Preview on the &amp;left</source>
        <translation>Vorschau auf &amp;linker Seite</translation>
    </message>
    <message>
        <location filename="../ui/dialogsettings.ui" line="94"/>
        <source>Pre&amp;view on right side</source>
        <translation>Vorschau auf &amp;rechter Seite</translation>
    </message>
    <message>
        <location filename="../ui/dialogsettings.ui" line="113"/>
        <source>Theme</source>
        <translation>Thema</translation>
    </message>
    <message>
        <location filename="../ui/dialogsettings.ui" line="119"/>
        <source>&amp;Default</source>
        <translation>&amp;Standard</translation>
    </message>
    <message>
        <location filename="../ui/dialogsettings.ui" line="126"/>
        <source>Dar&amp;k</source>
        <translation>&amp;Dunkel</translation>
    </message>
    <message>
        <location filename="../ui/dialogsettings.ui" line="139"/>
        <source>&lt;i&gt;(Restart needed)&lt;/I&gt;</source>
        <translation>&lt;i&gt;(Neustart erforderlich)&lt;/i&gt;</translation>
    </message>
    <message>
        <location filename="../ui/dialogsettings.ui" line="149"/>
        <source>Language</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/dialogsettings.ui" line="179"/>
        <source>Always enable preview zooming</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/dialogsettings.ui" line="186"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-style:italic;&quot;&gt;(Warning: preview may be inaccurate&lt;br/&gt;if checked.)&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/dialogsettings.ui" line="215"/>
        <source>Other</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/dialogsettings.ui" line="253"/>
        <source>Output messages</source>
        <translation>Ausgabe der Meldungen</translation>
    </message>
    <message>
        <location filename="../ui/dialogsettings.ui" line="196"/>
        <source>Dialogs</source>
        <translatorcomment>not sure about the use</translatorcomment>
        <translation>Einstellungen</translation>
    </message>
    <message>
        <location filename="../ui/dialogsettings.ui" line="202"/>
        <source>Use native color dialog</source>
        <translation>System-Farbwähler verwenden</translation>
    </message>
    <message>
        <location filename="../ui/dialogsettings.ui" line="163"/>
        <source>Preview</source>
        <translation>Vorschau</translation>
    </message>
    <message>
        <location filename="../ui/dialogsettings.ui" line="169"/>
        <source>Timeout (seconds)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/dialogsettings.ui" line="36"/>
        <source>Show institution logos</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/dialogsettings.ui" line="262"/>
        <source>Notify when scheduled update fails</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/dialogsettings.ui" line="304"/>
        <source>&amp;Ok</source>
        <translation>&amp;Ok</translation>
    </message>
</context>
<context>
    <name>FiltersView</name>
    <message>
        <location filename="../ui/filtersview.ui" line="14"/>
        <source>Form</source>
        <translation>GMIC</translation>
    </message>
</context>
<context>
    <name>GmicQt::ColorParameter</name>
    <message>
        <location filename="../src/FilterParameters/ColorParameter.cpp" line="200"/>
        <source>Select color</source>
        <translation>Farb-Auswahl</translation>
    </message>
</context>
<context>
    <name>GmicQt::DialogSettings</name>
    <message>
        <location filename="../src/DialogSettings.cpp" line="82"/>
        <source>Settings</source>
        <translation>Einstellungen</translation>
    </message>
    <message>
        <location filename="../src/DialogSettings.cpp" line="88"/>
        <source>Never</source>
        <translation>Niemals</translation>
    </message>
    <message>
        <location filename="../src/DialogSettings.cpp" line="89"/>
        <source>Daily</source>
        <translation>Täglich</translation>
    </message>
    <message>
        <location filename="../src/DialogSettings.cpp" line="90"/>
        <source>Weekly</source>
        <translation>Wöchentlich</translation>
    </message>
    <message>
        <location filename="../src/DialogSettings.cpp" line="91"/>
        <source>Every 2 weeks</source>
        <translation>Alle zwei Wochen</translation>
    </message>
    <message>
        <location filename="../src/DialogSettings.cpp" line="92"/>
        <source>Monthly</source>
        <translation>Monatlich</translation>
    </message>
    <message>
        <location filename="../src/DialogSettings.cpp" line="94"/>
        <source>At launch (debug)</source>
        <translation>Beim Starten (Debug)</translation>
    </message>
    <message>
        <location filename="../src/DialogSettings.cpp" line="102"/>
        <source>Output messages</source>
        <translation>Ausgabe der Meldungen</translation>
    </message>
    <message>
        <location filename="../src/DialogSettings.cpp" line="103"/>
        <source>Quiet (default)</source>
        <translation>Keine Ausgabe (Standard)</translation>
    </message>
    <message>
        <location filename="../src/DialogSettings.cpp" line="104"/>
        <source>Verbose (console)</source>
        <translation>Ausführlich (Konsole)</translation>
    </message>
    <message>
        <location filename="../src/DialogSettings.cpp" line="105"/>
        <source>Verbose (log file)</source>
        <translation>Ausführlich (Log-Datei)</translation>
    </message>
    <message>
        <location filename="../src/DialogSettings.cpp" line="106"/>
        <source>Very verbose (console)</source>
        <translation>Sehr ausführlich (Konsole)</translation>
    </message>
    <message>
        <location filename="../src/DialogSettings.cpp" line="107"/>
        <source>Very verbose (log file)</source>
        <translation>Sehr ausführlich (Log-Datei)</translation>
    </message>
    <message>
        <location filename="../src/DialogSettings.cpp" line="108"/>
        <source>Debug (console)</source>
        <translation>Debuggen (Konsole)</translation>
    </message>
    <message>
        <location filename="../src/DialogSettings.cpp" line="109"/>
        <source>Debug (log file)</source>
        <translation>Debuggen (Log-Datei)</translation>
    </message>
    <message>
        <location filename="../src/DialogSettings.cpp" line="125"/>
        <source>Check to use Native/OS color dialog, uncheck to use Qt&apos;s</source>
        <translation>Auswählen, um System-Farbwähler zu nutzen, aus für Qt-Farbwähler</translation>
    </message>
</context>
<context>
    <name>GmicQt::FileParameter</name>
    <message>
        <location filename="../src/FilterParameters/FileParameter.cpp" line="157"/>
        <location filename="../src/FilterParameters/FileParameter.cpp" line="160"/>
        <location filename="../src/FilterParameters/FileParameter.cpp" line="163"/>
        <source>Select a file</source>
        <translation>Datei auswählen</translation>
    </message>
</context>
<context>
    <name>GmicQt::FilterParametersWidget</name>
    <message>
        <location filename="../src/FilterParameters/FilterParametersWidget.cpp" line="43"/>
        <location filename="../src/FilterParameters/FilterParametersWidget.cpp" line="251"/>
        <source>&lt;i&gt;Select a filter&lt;/i&gt;</source>
        <translation>&lt;i&gt;Filter auswählen&lt;/i&gt;</translation>
    </message>
    <message>
        <location filename="../src/FilterParameters/FilterParametersWidget.cpp" line="218"/>
        <source>&lt;i&gt;No parameters&lt;/i&gt;</source>
        <translation>&lt;i&gt;Keine Parameter anzugeben&lt;/i&gt;</translation>
    </message>
    <message>
        <location filename="../src/FilterParameters/FilterParametersWidget.cpp" line="223"/>
        <source>Error parsing filter parameters

</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>GmicQt::FiltersPresenter</name>
    <message>
        <location filename="../src/FilterSelector/FiltersPresenter.cpp" line="498"/>
        <source>Unknown filter</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/FilterSelector/FiltersPresenter.cpp" line="606"/>
        <source>Cannot find this fave&apos;s original filter
</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>GmicQt::FiltersView</name>
    <message>
        <location filename="../src/FilterSelector/FiltersView/FiltersView.cpp" line="350"/>
        <source>Remove fave</source>
        <translation>Kein Favorit mehr</translation>
    </message>
    <message>
        <location filename="../src/FilterSelector/FiltersView/FiltersView.cpp" line="670"/>
        <source>Rename Fave</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/FilterSelector/FiltersView/FiltersView.cpp" line="672"/>
        <source>Remove Fave</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/FilterSelector/FiltersView/FiltersView.cpp" line="674"/>
        <source>Clone Fave</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/FilterSelector/FiltersView/FiltersView.cpp" line="678"/>
        <source>Add Fave</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/FilterSelector/FiltersView/FiltersView.cpp" line="697"/>
        <source>Remove All</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/FilterSelector/FiltersView/FiltersView.cpp" line="704"/>
        <source>%1 (%2 %3)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/FilterSelector/FiltersView/FiltersView.cpp" line="704"/>
        <source>Filters</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/FilterSelector/FiltersView/FiltersView.cpp" line="704"/>
        <source>Filter</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/FilterSelector/FiltersView/FiltersView.cpp" line="351"/>
        <source>Do you really want to remove the following fave?

%1
</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>GmicQt::FolderParameter</name>
    <message>
        <location filename="../src/FilterParameters/FolderParameter.cpp" line="135"/>
        <source>Select a folder</source>
        <translation>Ordner wählen</translation>
    </message>
</context>
<context>
    <name>GmicQt::GmicProcessor</name>
    <message>
        <location filename="../src/GmicProcessor.cpp" line="299"/>
        <source>Image #%1 returned by filter has %2 channels (should be at most 4)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/GmicProcessor.cpp" line="333"/>
        <source>Image #%1 returned by filter has %2 channels
(should be at most 4)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>GmicQt::HeadlessProcessor</name>
    <message>
        <location filename="../src/HeadlessProcessor.cpp" line="81"/>
        <source>At least a filter path or a filter command must be provided.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/HeadlessProcessor.cpp" line="83"/>
        <source>Custom command (%1)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/HeadlessProcessor.cpp" line="91"/>
        <source>Cannot find filter matching path %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/HeadlessProcessor.cpp" line="98"/>
        <source>Error parsing filter parameters definition for filter:

%1

Cannot retrieve default parameters.

%2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/HeadlessProcessor.cpp" line="116"/>
        <source>Error parsing supplied command: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/HeadlessProcessor.cpp" line="119"/>
        <source>Supplied command (%1) does not match path (%2), (should be %3).</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/HeadlessProcessor.cpp" line="233"/>
        <source>Filter execution failed, but with no error message.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>GmicQt::InOutPanel</name>
    <message>
        <location filename="../src/Widgets/InOutPanel.cpp" line="63"/>
        <source>Input layers</source>
        <translation>Ursprungs-Ebenen</translation>
    </message>
    <message>
        <location filename="../src/Widgets/InOutPanel.cpp" line="69"/>
        <source>None</source>
        <translation>Keine</translation>
    </message>
    <message>
        <location filename="../src/Widgets/InOutPanel.cpp" line="70"/>
        <source>Active (default)</source>
        <translation>Aktive (Standard)</translation>
    </message>
    <message>
        <location filename="../src/Widgets/InOutPanel.cpp" line="71"/>
        <source>All</source>
        <translation>Alle</translation>
    </message>
    <message>
        <location filename="../src/Widgets/InOutPanel.cpp" line="72"/>
        <source>Active and below</source>
        <translation>Aktive und darunter liegende</translation>
    </message>
    <message>
        <location filename="../src/Widgets/InOutPanel.cpp" line="73"/>
        <source>Active and above</source>
        <translation>Aktive und darüber liegende</translation>
    </message>
    <message>
        <location filename="../src/Widgets/InOutPanel.cpp" line="74"/>
        <source>All visible</source>
        <translation>Alle sichtbaren</translation>
    </message>
    <message>
        <location filename="../src/Widgets/InOutPanel.cpp" line="75"/>
        <source>All invisible</source>
        <translation>Alle nicht sichtbaren</translation>
    </message>
    <message>
        <location filename="../src/Widgets/InOutPanel.cpp" line="86"/>
        <source>Output mode</source>
        <translation>Ziel</translation>
    </message>
    <message>
        <location filename="../src/Widgets/InOutPanel.cpp" line="92"/>
        <source>In place (default)</source>
        <translation>Ebene ersetzen (Standard)</translation>
    </message>
    <message>
        <location filename="../src/Widgets/InOutPanel.cpp" line="93"/>
        <source>New layer(s)</source>
        <translation>Neue Ebene(n)</translation>
    </message>
    <message>
        <location filename="../src/Widgets/InOutPanel.cpp" line="94"/>
        <source>New active layer(s)</source>
        <translation>Neue aktive Ebene(n)</translation>
    </message>
    <message>
        <location filename="../src/Widgets/InOutPanel.cpp" line="95"/>
        <source>New image</source>
        <translation>Neues Bild</translation>
    </message>
    <message>
        <location filename="../src/Widgets/InOutPanel.cpp" line="206"/>
        <source>Input / Output</source>
        <translation>Quellen und Ziel</translation>
    </message>
    <message>
        <location filename="../src/Widgets/InOutPanel.cpp" line="208"/>
        <source>Input</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/Widgets/InOutPanel.cpp" line="210"/>
        <source>Output</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>GmicQt::LanguageSelectionWidget</name>
    <message>
        <location filename="../src/Widgets/LanguageSelectionWidget.cpp" line="53"/>
        <source>System default (%1)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/Widgets/LanguageSelectionWidget.cpp" line="62"/>
        <source>Translations are very likely to be incomplete.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>GmicQt::MainWindow</name>
    <message>
        <location filename="../src/MainWindow.cpp" line="109"/>
        <source>Add fave</source>
        <translation>Als Favorit merken</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="111"/>
        <source>Reset parameters to default values</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="117"/>
        <source>Copy G&apos;MIC command to clipboard</source>
        <translation>G&apos;MIC-Befehl in die Zwischenablage kopieren</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="124"/>
        <source>Rename fave</source>
        <translation>Favorit umbenennen</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="126"/>
        <source>Remove fave</source>
        <translation>Kein Favorit mehr</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="130"/>
        <source>Expand/Collapse all</source>
        <translation>Alles aufklappen/einklappen</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="132"/>
        <source>G&apos;MIC (https://gmic.eu)&lt;br/&gt;GREYC (https://www.greyc.fr)&lt;br/&gt;CNRS (https://www.cnrs.fr)&lt;br/&gt;Normandy University (https://www.unicaen.fr)&lt;br/&gt;Ensicaen (https://www.ensicaen.fr)</source>
        <translation>G&apos;MIC (https://gmic.eu)&lt;br/&gt;GREYC (https://www.greyc.fr)&lt;br/&gt;CNRS (https://www.cnrs.fr)&lt;br/&gt;Normandie Université (https://www.unicaen.fr)&lt;br/&gt;Ensicaen (https://www.ensicaen.fr)</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="139"/>
        <source>Selection mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="177"/>
        <source>Update filters</source>
        <translation>Filter aktualisieren</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="231"/>
        <source>Manage visible tags
(Right-click on a fave or a filter to set/remove tags)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="353"/>
        <source>Update completed</source>
        <translation>Aktualisierung ist durchgeführt</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="353"/>
        <location filename="../src/MainWindow.cpp" line="355"/>
        <location filename="../src/MainWindow.cpp" line="475"/>
        <source>Filter definitions have been updated.</source>
        <translation>Die Filter-Definitionen wurden aktualisiert.</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="358"/>
        <source>No download was needed.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="411"/>
        <source>Plugin was called with a filter path with no matching filter:

Path: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="419"/>
        <location filename="../src/MainWindow.cpp" line="446"/>
        <source>Error parsing filter parameters definition for filter:

%1

Cannot retrieve default parameters.

%2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="432"/>
        <source>Plugin was called with a command that cannot be recognized as a filter:

Command: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="427"/>
        <source>Plugin was called with a command that cannot be parsed:

%1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="436"/>
        <source>Plugin was called with a command that does not match the provided path:

Path: %1
Command: %2
Command found for this path : %3</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="471"/>
        <source>Filters update could not be achieved</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="597"/>
        <source>The update could not be achieved&lt;br&gt;because of the following errors:&lt;br&gt;</source>
        <translation>Wegen der folgenden Fehler konnte&lt;br/&gt;die Aktualisierung nicht durchgeführt werden:&lt;br/&gt;</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="603"/>
        <source>Update error</source>
        <translation>Fehler bei der Aktualisierung</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="803"/>
        <source>Error</source>
        <translation>Fehler</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="899"/>
        <source>Waiting for cancelled jobs...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="1272"/>
        <source>Import faves</source>
        <translation>Favoriten importieren</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="1272"/>
        <source>Do you want to import faves from file below?&lt;br/&gt;%1</source>
        <translation>Möchten Sie Favoriten aus dieser Datei importieren?&lt;br/&gt;%1</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="1275"/>
        <source>Don&apos;t ask again</source>
        <translation>Nicht mehr fragen</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="1387"/>
        <source>Confirmation</source>
        <translation>Bestätigung</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="1387"/>
        <source>A gmic command is running.&lt;br&gt;Do you really want to close the plugin?</source>
        <translation>Ein GMIC-Kommando ist aktiv.&lt;br&gt;Wollen Sie das Plugin wirklich schließen?</translation>
    </message>
</context>
<context>
    <name>GmicQt::MultilineTextParameterWidget</name>
    <message>
        <location filename="../src/FilterParameters/MultilineTextParameterWidget.cpp" line="41"/>
        <source>Ctrl+Return</source>
        <translation>Strg+Enter</translation>
    </message>
</context>
<context>
    <name>GmicQt::ProgressInfoWidget</name>
    <message>
        <location filename="../src/Widgets/ProgressInfoWidget.cpp" line="49"/>
        <source>G&apos;MIC-Qt Plug-in progression</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/Widgets/ProgressInfoWidget.cpp" line="52"/>
        <source>Abort</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <location filename="../src/Widgets/ProgressInfoWidget.cpp" line="150"/>
        <source>Updating filters...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/Widgets/ProgressInfoWidget.cpp" line="205"/>
        <location filename="../src/Widgets/ProgressInfoWidget.cpp" line="218"/>
        <source>[Processing %1 | %2]</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/Widgets/ProgressInfoWidget.cpp" line="220"/>
        <source>[Processing %1]</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>GmicQt::ProgressInfoWindow</name>
    <message>
        <location filename="../src/Widgets/ProgressInfoWindow.cpp" line="49"/>
        <source>G&apos;MIC-Qt Plug-in progression</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/Widgets/ProgressInfoWindow.cpp" line="141"/>
        <source>%1 seconds</source>
        <translation>%1 Sekunden</translation>
    </message>
    <message>
        <location filename="../src/Widgets/ProgressInfoWindow.cpp" line="151"/>
        <source>[Processing %1 | %2]</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/Widgets/ProgressInfoWindow.cpp" line="153"/>
        <source>[Processing %1]</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>GmicQt::SearchFieldWidget</name>
    <message>
        <location filename="../src/Widgets/SearchFieldWidget.cpp" line="79"/>
        <source>Search</source>
        <translation>Suchen</translation>
    </message>
    <message>
        <location filename="../src/Widgets/SearchFieldWidget.cpp" line="80"/>
        <source>Search in filters list (%1)</source>
        <translation>In Filter-Liste suchen (%1)</translation>
    </message>
</context>
<context>
    <name>GmicQt::Updater</name>
    <message>
        <location filename="../src/Updater.cpp" line="198"/>
        <source>Error downloading %1 (empty file?)</source>
        <translation>Fehler beim Laden von %1 (Leere Datei?)</translation>
    </message>
    <message>
        <location filename="../src/Updater.cpp" line="207"/>
        <source>Could not read/decompress %1</source>
        <translation>%1 ist nicht lesbar oder kann nicht entpackt werden</translation>
    </message>
    <message>
        <location filename="../src/Updater.cpp" line="212"/>
        <source>Error writing file %1</source>
        <translation>Fehler beim Schreiben der Datei %1</translation>
    </message>
    <message>
        <location filename="../src/Updater.cpp" line="229"/>
        <source>Error downloading %1&lt;br/&gt;Error %2: %3</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/Updater.cpp" line="265"/>
        <source>Download timeout: %1</source>
        <translation>Zeitüberschreitung beim Herunterladen : %1</translation>
    </message>
</context>
<context>
    <name>GmicQt::VisibleTagSelector</name>
    <message>
        <location filename="../src/Widgets/VisibleTagSelector.cpp" line="55"/>
        <source>Show All Filters</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/Widgets/VisibleTagSelector.cpp" line="59"/>
        <source>Show %1 Tags</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>GmicQt::ZoomLevelSelector</name>
    <message>
        <location filename="../src/Widgets/ZoomLevelSelector.cpp" line="54"/>
        <source>Zoom in</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/Widgets/ZoomLevelSelector.cpp" line="55"/>
        <source>Zoom out</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/Widgets/ZoomLevelSelector.cpp" line="56"/>
        <source>Reset zoom</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/Widgets/ZoomLevelSelector.cpp" line="156"/>
        <source>Warning: Preview may be inaccurate (zoom factor has been modified)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>HeadlessProgressDialog</name>
    <message>
        <location filename="../ui/headlessprogressdialog.ui" line="14"/>
        <source>Dialog</source>
        <translatorcomment>guessed from french translation</translatorcomment>
        <translation>Fortschritt</translation>
    </message>
    <message>
        <location filename="../ui/headlessprogressdialog.ui" line="68"/>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
</context>
<context>
    <name>InOutPanel</name>
    <message>
        <location filename="../ui/inoutpanel.ui" line="40"/>
        <source>Input / Output</source>
        <translation>Quellen und Ziel</translation>
    </message>
    <message>
        <location filename="../ui/inoutpanel.ui" line="47"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <location filename="../ui/inoutpanel.ui" line="92"/>
        <source>Input layers</source>
        <translation>Ursprungs-Ebenen</translation>
    </message>
    <message>
        <location filename="../ui/inoutpanel.ui" line="115"/>
        <source>Output mode</source>
        <translation>Ziel</translation>
    </message>
</context>
<context>
    <name>JpegQualityDialog</name>
    <message>
        <location filename="../src/Host/None/jpegqualitydialog.ui" line="14"/>
        <source>Dialog</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/Host/None/jpegqualitydialog.ui" line="20"/>
        <location filename="../src/Host/None/JpegQualityDialog.cpp" line="12"/>
        <source>JPEG Quality</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/Host/None/jpegqualitydialog.ui" line="28"/>
        <source>0</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/Host/None/jpegqualitydialog.ui" line="42"/>
        <source>100</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/Host/None/jpegqualitydialog.ui" line="60"/>
        <source>Always use this quality for this execution of G&apos;MIC-Qt</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/Host/None/jpegqualitydialog.ui" line="85"/>
        <source>&amp;Cancel</source>
        <translation type="unfinished">&amp;Abbruch</translation>
    </message>
    <message>
        <location filename="../src/Host/None/jpegqualitydialog.ui" line="92"/>
        <source>&amp;Ok</source>
        <translation type="unfinished">&amp;Ok</translation>
    </message>
</context>
<context>
    <name>LanguageSelectionWidget</name>
    <message>
        <location filename="../ui/languageselectionwidget.ui" line="14"/>
        <source>Form</source>
        <translation>GMIC</translation>
    </message>
    <message>
        <location filename="../ui/languageselectionwidget.ui" line="35"/>
        <source>&lt;i&gt;(Restart needed)&lt;/i&gt;</source>
        <translation>&lt;i&gt;(Neustart erforderlich)&lt;/i&gt;</translation>
    </message>
    <message>
        <location filename="../ui/languageselectionwidget.ui" line="48"/>
        <source>Translate filters (WIP)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../ui/mainwindow.ui" line="18"/>
        <source>Form</source>
        <translation>GMIC</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="176"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Download filter definitions from remote sources&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Filter-Definitionen von externen Quellen laden&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="179"/>
        <source>Internet</source>
        <translation>Internet</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="511"/>
        <source>TextLabel</source>
        <translatorcomment>why empty?</translatorcomment>
        <translation>TextLabel</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="248"/>
        <location filename="../ui/mainwindow.ui" line="255"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="14"/>
        <source>MainWindow</source>
        <translation type="unfinished">MainWindow</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="401"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Enable/disable preview&lt;br/&gt;(Ctrl+P)&lt;br/&gt;(right click on preview image for instant swapping)&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="404"/>
        <source>Preview</source>
        <translation>Vorschau</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="495"/>
        <source>Settings...</source>
        <translation>Einstellungen...</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="524"/>
        <source>&amp;Cancel</source>
        <translation>&amp;Abbruch</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="537"/>
        <source>&amp;Fullscreen</source>
        <translation>&amp;Vollbild</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="550"/>
        <source>&amp;Apply</source>
        <translation>&amp;Anwenden</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="563"/>
        <source>&amp;OK</source>
        <translation>&amp;Ok</translation>
    </message>
</context>
<context>
    <name>MultilineTextParameterWidget</name>
    <message>
        <location filename="../ui/multilinetextparameterwidget.ui" line="14"/>
        <source>Form</source>
        <translation>GMIC</translation>
    </message>
    <message>
        <location filename="../ui/multilinetextparameterwidget.ui" line="29"/>
        <source>Update</source>
        <translation>Aktualisieren</translation>
    </message>
</context>
<context>
    <name>ProgressInfoWidget</name>
    <message>
        <location filename="../ui/progressinfowidget.ui" line="14"/>
        <source>Form</source>
        <translation>GMIC</translation>
    </message>
    <message>
        <location filename="../ui/progressinfowidget.ui" line="48"/>
        <source>Abort</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <location filename="../ui/progressinfowidget.ui" line="55"/>
        <source>TextLabel</source>
        <translation>TextLabel</translation>
    </message>
</context>
<context>
    <name>ProgressInfoWindow</name>
    <message>
        <location filename="../ui/progressinfowindow.ui" line="14"/>
        <source>MainWindow</source>
        <translation>MainWindow</translation>
    </message>
    <message>
        <location filename="../ui/progressinfowindow.ui" line="30"/>
        <location filename="../ui/progressinfowindow.ui" line="50"/>
        <source>TextLabel</source>
        <translation>TextLabel</translation>
    </message>
    <message>
        <location filename="../ui/progressinfowindow.ui" line="72"/>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/Host/None/host_none.cpp" line="74"/>
        <source>Select an image to open...</source>
        <translation>Bild zum Laden auswählen...</translation>
    </message>
    <message>
        <location filename="../src/Host/None/host_none.cpp" line="80"/>
        <source>Error</source>
        <translation>Fehler</translation>
    </message>
    <message>
        <location filename="../src/Host/None/host_none.cpp" line="80"/>
        <source>Could not open file.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/Host/None/host_none.cpp" line="84"/>
        <source>Default image</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/FilterSelector/FiltersView/FiltersView.cpp" line="81"/>
        <source>Visible</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/FilterSelector/FiltersPresenter.cpp" line="103"/>
        <source>Available filters (%1)</source>
        <translation>Verfügbare Filter (%1)</translation>
    </message>
    <message>
        <location filename="../src/Misc.cpp" line="330"/>
        <source>List %1 cannot be merged considering theses runs: %2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/Tags.cpp" line="151"/>
        <source>%1 Tag</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/Tags.cpp" line="157"/>
        <source>None</source>
        <translation type="unfinished">Keine</translation>
    </message>
    <message>
        <location filename="../src/Tags.cpp" line="158"/>
        <source>Red</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/Tags.cpp" line="159"/>
        <source>Green</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/Tags.cpp" line="160"/>
        <source>Blue</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/Tags.cpp" line="161"/>
        <source>Cyan</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/Tags.cpp" line="162"/>
        <source>Magenta</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/Tags.cpp" line="163"/>
        <source>Yellow</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/LanguageSettings.cpp" line="127"/>
        <source>Could not install translator for file %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/LanguageSettings.cpp" line="130"/>
        <source>Could not load translation file %1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SearchFieldWidget</name>
    <message>
        <location filename="../ui/SearchFieldWidget.ui" line="20"/>
        <source>Frame</source>
        <translation>Frame</translation>
    </message>
</context>
<context>
    <name>ZoomLevelSelector</name>
    <message>
        <location filename="../ui/zoomlevelselector.ui" line="20"/>
        <source>Form</source>
        <translation>GMIC</translation>
    </message>
</context>
<context>
    <name>gmic_qt_standalone::ImageDialog</name>
    <message>
        <location filename="../src/Host/None/ImageDialog.cpp" line="71"/>
        <source>G&apos;MIC-Qt filter output</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/Host/None/ImageDialog.cpp" line="82"/>
        <source>Close</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/Host/None/ImageDialog.cpp" line="85"/>
        <source>Save as...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/Host/None/ImageDialog.cpp" line="120"/>
        <source>%1 file (*.%2)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/Host/None/ImageDialog.cpp" line="141"/>
        <source>Save image as...</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>gmic_qt_standalone::ImageView</name>
    <message>
        <location filename="../src/Host/None/ImageDialog.cpp" line="63"/>
        <source>Error</source>
        <translation type="unfinished">Fehler</translation>
    </message>
    <message>
        <location filename="../src/Host/None/ImageDialog.cpp" line="63"/>
        <source>Could not write image file %1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
